@@ -49,20 +49,19 @@ class TaskModel:
         )
 
         log.info(
-            "Loaded task model, config: {}, tokenizer: {}, model: {} ".format(type(self.config), type(self.tokenizer),
-                                                                              type(self.model)))
+            "Loaded task model, config: {}, tokenizer: {}, "
+            "model: {}, config:{} ".format(type(self.config),
+                                           type(self.tokenizer),
+                                           type(self.model),
+                                           str(self.config.get_config_dict()))
+        )
 
         self._freeze_parameters()
 
     def _freeze_parameters(self):
-        if self.model is None:
-            return
-
-        if self._model_args.freeze_parameter and hasattr(self.model, self._model_args.freeze_parameter):
-            freeze_model = eval("self.model." + self._model_args.freeze_parameter)
-            if hasattr(freeze_model, "parameters"):
-                for param in freeze_model.parameters():
-                    param.requires_grad = False
+        # Currently, freezing the main paramerter is supported only
+        self._freeze_weights_main()
+        # self._freeze_parameters_others()
 
         if hasattr(self.model, 'num_parameters'):
             log.info("num params:" + str(self.model.num_parameters()))
@@ -73,6 +72,25 @@ class TaskModel:
             for name, param in self.model.named_parameters():
                 log.info("{}:{}".format(name, param.size()))
 
+    def _freeze_weights_main(self):
+        if self.model is None or not self._model_args.freeze_main:
+            return
+
+        main_parameters = eval("self.model." + self.task_model.main_parameter)
+        if hasattr(main_parameters, "parameters"):
+            for param in main_parameters.parameters():
+                param.requires_grad = False
+
+    def _freeze_weights_others(self):
+        if self.model is None:
+            return
+
+        if self._model_args.freeze_parameter and hasattr(self.model, self._model_args.freeze_parameter):
+            freeze_model = eval("self.model." + self._model_args.freeze_parameter)
+            if hasattr(freeze_model, "parameters"):
+                for param in freeze_model.parameters():
+                    param.requires_grad = False
+
     def _build_task_model(self, modelArgs, model_class=None):
         mode_cache_dir = modelArgs.model_pretrained_dir if not modelArgs.not_use_pretrained else modelArgs.model_finetuned_dir
 
@@ -212,23 +230,20 @@ class TaskTrainer:
 
 
 class TransformerTask:
-    def __init__(self, task_args: TaskArguments,
+    def __init__(self, task_name, task_args: TaskArguments,
                  dataProcessor, model_class=None, compute_metric=None):
         log.info("Create a TransformerTask with arguments: ")
         log.info(json.dumps(task_args, default=lambda obj: obj.__dict__, indent=True))
 
         self.task_args = task_args
+        self.task_args.validate_and_set_task_name(task_name)
+        self._training_args = task_args.training_args
+
         self._taskModel = TaskModel(task_args.model_args, model_class)
         self._taskData = TaskData(task_args.data_args, self._taskModel.tokenizer, dataProcessor,
                                   task_args.training_args.local_rank)
-        self.task_args.training_args.validate()
-        self.task_args.training_args.output_dir = join_path(
-            self.task_args.training_args.output_dir,
-            self.task_args.model_args.model_name
-        )
         self._taskTrainer = TaskTrainer(task_args.training_args, self._taskModel,
                                         self._taskData, compute_metric)
-        self._training_args = task_args.training_args
 
     def _log_task_start(self):
         log.warning(
@@ -266,4 +281,4 @@ class TransformerTask:
 
 class DefaultTask(TransformerTask):
     def __init__(self, dataProcessorClass, model_class=None, compute_metric=None):
-        super().__init__(parse_tasks_args(), dataProcessorClass, model_class, compute_metric)
+        super().__init__("default", parse_tasks_args(), dataProcessorClass, model_class, compute_metric)
